@@ -566,7 +566,7 @@ class CreateClusterRouteTableResponse(AbstractModel):
 
 
 class DataDisk(AbstractModel):
-    """描述了k8s节点数据盘相关配置与信息。
+    """Described the configuration and information of k8s node data disk.
 
     """
 
@@ -1517,13 +1517,13 @@ class InstanceAdvancedSettings(AbstractModel):
 
 
 class InstanceDataDiskMountSetting(AbstractModel):
-    """CVM实例数据盘挂载配置
+    """CVM instance data disk mount configuration
 
     """
 
 
 class Label(AbstractModel):
-    """k8s中标签，一般以数组的方式存在
+    """k8s tags, generally exist as an array
 
     """
 
@@ -1535,8 +1535,8 @@ class LoginSettings(AbstractModel):
 
     def __init__(self):
         """
-        :param Password: Login password of the instance. The password requirements vary among different operating systems: <br><li>For Linux instances, the password must be 8-30 characters long and contain at least two of the following categories: [a-z], [A-Z], [0-9] and [( ) \` ~ ! @ # $ % ^ & *  - + = | { } [ ] : ; ' , . ? / ]. <br><li>For Windows instances, the password must be 12-30 characters long and contain at least three of the following categories: [a-z], [A-Z], [0-9] and [( ) \` ~ ! @ # $ % ^ & * - + = | { } [ ] : ; ' , . ? /]. <br><br>If this parameter is not specified, a random password will be generated and sent to you via the Message Center.
-Note: this field may return null, indicating that no valid values can be obtained.
+        :param Password: Login password of the instance. The password requirements vary among different operating systems: <br><li>For Linux instances, the password must be 8-16 characters long and contain at least one character from two of the following categories: [a-z, A-Z], [0-9] and [( ) ` ~ ! @ # $ % ^ & * - + = | { } [ ] : ; ' , . ? / ]. <br><li>For Windows instances, the password must be 12-16 characters long and contain at least one character from three of the following categories: [a-z], [A-Z], [0-9] and [( ) ` ~ ! @ # $ % ^ & * - + = { } [ ] : ; ' , . ? /]. <br><br>If this parameter is not specified, a random password will be generated and sent to you via the Message Center.
+Note: This field may return null, indicating that no valid value is found.
         :type Password: str
         :param KeyIds: List of key IDs. After an instance is associated with a key, you can access the instance with the private key in the key pair. You can call `DescribeKeyPairs` to obtain `KeyId`. Key and password cannot be specified at the same time. Windows instances do not support keys. Currently, you can only specify one key when purchasing an instance.
 Note: This field may return null, indicating that no valid value is found.
@@ -1717,6 +1717,6 @@ class RunSecurityServiceEnabled(AbstractModel):
 
 
 class TagSpecification(AbstractModel):
-    """标签描述列表。通过指定该参数可以同时绑定标签到相应的资源实例，当前仅支持绑定标签到云主机实例。
+    """List of tag descriptions. By specifying this parameter, you can bind tags to corresponding resource instances at the same time. Currently, only tags are bound to cloud host instances.
 
     """
\ No newline at end of file
